
#ifndef _romdiff_h
#define _romdiff_h

struct ROMdiff {
	int offset;
	int newvalue;
};

extern ROMdiff tosdiff[];

#endif	/* !_romdiff_h */
